@@ -23,3 +23,8 @@
  ELPA_FOR_ALL_2STAGE_COMPLEX_KERNELS_AND_DEFAULT(FORTRAN_CONSTANT)
 #undef ELPA_2STAGE_NUMBER_OF_COMPLEX_KERNELS
  FORTRAN_CONSTANT(ELPA_2STAGE_NUMBER_OF_COMPLEX_KERNELS, & NEWLINE (0 ELPA_FOR_ALL_2STAGE_COMPLEX_KERNELS(ELPA_ENUM_SUM)))
+
+
+! Autotune
+ ELPA_FOR_ALL_AUTOTUNE_LEVELS(FORTRAN_CONSTANT)
+ ELPA_FOR_ALL_AUTOTUNE_DOMAINS(FORTRAN_CONSTANT)
